==> spip_4.2.12+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Нема повідомлень на форумі',

	// B
	'bouton_radio_articles_futurs' => 'тільки для майбутніх статей  (не приймати рішення по базі даних).',
	'bouton_radio_articles_tous' => 'до всіх статтей без винятків',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'до всіх статтей, крім тих, форум яких відключено.',
	'bouton_radio_enregistrement_obligatoire' => 'Потрібна реєстрація.  (Користувачі повинні зареєструватися, направивши свої електронні адреси до того, як зможуть розмістити внески).',
	'bouton_radio_moderation_priori' => 'Премодерація (Внески  будуть відображатися публічно тільки після перевірки адміністраторами).',
	'bouton_radio_modere_abonnement' => 'за підпискою',
	'bouton_radio_modere_posteriori' => 'пост-модерація',
	'bouton_radio_modere_priori' => 'премодерація',
	'bouton_radio_publication_immediate' => 'Публікація коментарів без перевірки  (адміністратори можуть   видалити їх).',

	// D
	'documents_interdits_forum' => 'Заборонено додавати файли у коментарі форума',

	// E
	'erreur_enregistrement_message' => 'Ваше повідомлення не може бути записано через технічні проблеми.',
	'extensions_autorisees' => 'Авторизовані розширення:',
	'extensions_autorisees_toutes' => 'усі',

	// F
	'form_pet_message_commentaire' => 'Залишити коментар',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'Ви більше не маєте доступу до цих форумів.',
	'forum_attention_dix_caracteres' => 'Увага! Текст вашого коментаря має містити щонайменше 10 символів.',
	'forum_attention_message_non_poste' => 'Ваше коментар ще не опублікован на сайті!',
	'forum_attention_nb_caracteres_mini' => '<b>Увага!</b> Ваш коментар має бути не менше @min@ символів.',
	'forum_attention_trois_caracteres' => '<b>Увага!</b> Заголовок має бути не менше трьох символів.',
	'forum_attention_trop_caracteres' => '<b>Увага!</b> Ваш коментар містить (@compte@ caractères) символів, ми можемо його опублікувати якщо розмір не перевищує @max@ символів.',
	'forum_avez_selectionne' => 'Ви обрали:',
	'forum_cliquer_retour' => 'Натисніть <a href=\'@retour_forum@\'>сюди</a> аби продовжити.',
	'forum_envoyer' => 'Відправити',
	'forum_forum' => 'форум',
	'forum_info_modere' => 'На цьому форумі здійснюється премодерація: ваш коментар буде опубліковано після перевірки адміністратором.',
	'forum_lien_hyper' => 'Гіпертекстове посилання',
	'forum_message' => 'Ваш коментар',
	'forum_message_definitif' => 'Надіслати до публікації',
	'forum_message_trop_long' => 'Ваш коментар занадто довгий. Максимальний розмір становить 20000 символів.',
	'forum_ne_repondez_pas' => 'Не відповідайте на цей лист, але перейдіть на форум за наступним посиланням:',
	'forum_page_url' => '(Якщо ваше повідомлення відноситься до статті, опублікованої на сайті, або до сторінки, що пропонує подальшу інформацію, ви можете вказати назву сторінки та її URL-адресу.)',
	'forum_permalink' => 'Постійне посилання на цей коментар',
	'forum_poste_par' => '@parauteur@ прокоментував вашу статтю «@titre@».',
	'forum_poste_par_court' => '@parauteur@ прокоментував',
	'forum_poste_par_generique' => '@parauteur@ прокоментував (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Хто ви?',
	'forum_saisie_texte_info' => 'Ви можете використовувати такі позначення в тексті: <code>[-&gt;url] {{жирний}} {курсив} &lt;quote&gt; &lt;code&gt;</code> і теги HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Щоб створити параграф двічі натисніть enter.',
	'forum_texte' => 'Текст повідомлення',
	'forum_titre' => 'Тема',
	'forum_url' => 'Ваш сайт',
	'forum_valider' => 'Підтвердіть вибір',
	'forum_voir_avant' => 'Попередній перегляд',
	'forum_votre_email' => 'Ваш email',
	'forum_votre_nom' => 'Ваше ім’я',
	'forum_vous_enregistrer' => 'Тільки зареєстровані користувачі можуть залишати коментарі. Якщо ви ще не зареєстровані, ви можете',
	'forum_vous_inscrire' => 'зареєструватися',

	// I
	'icone_bruler_message' => 'Помітити як спам',
	'icone_bruler_messages' => 'Поскаржитись на спам',
	'icone_legitimer_message' => 'Помітити як НЕ спам',
	'icone_poster_message' => 'Опублікувати коментар',
	'icone_suivi_forum' => 'Моніторинг форуму загального сайту: @nb_forums@ коментарі(в)',
	'icone_suivi_forums' => 'Управління форумами',
	'icone_supprimer_message' => 'Видалити коментар',
	'icone_supprimer_messages' => 'Видалити коментарі',
	'icone_valider_message' => 'Підтвердити коментар',
	'icone_valider_messages' => 'Опублікувати коментар',
	'icone_valider_repondre_message' => 'Затвердити та відповісти',
	'info_1_message_forum' => '1 повідомлення',
	'info_activer_forum_public' => 'Для активації форумів на публічній сторінці сайту оберіть режим модерації:',
	'info_appliquer_choix_moderation' => 'Застосувати режим модерації:',
	'info_config_forums_prive' => 'У приватній частині сайту ви можете активувати декілька типів форумів:',
	'info_config_forums_prive_admin' => 'Форум для адміністраторів сайту:',
	'info_config_forums_prive_global' => 'Форум, відкритий для всіх редакторів:',
	'info_config_forums_prive_objets' => 'Форум до кожної статті, новини, веб-сайту тощо:',
	'info_desactiver_forum_public' => 'Вимкнути використання форумів  на загальному сайті. Ви зможете дозволити коментарі до певної статті, але вони будуть заборонені до рубрик, новин тощо.',
	'info_envoi_forum' => 'Відправка форумів авторам статей',
	'info_fonctionnement_forum' => 'Робота форуму:',
	'info_forcer_previsualisation_court' => 'Обов’язколвий попередній перегляд',
	'info_forcer_previsualisation_long' => 'Обов’язковий попередній перегляд перед відправкою коментаря',
	'info_forums_liees_mot' => 'Повідомлень на форумі, пов’язанному з цим ключовим словом',
	'info_gauche_suivi_forum_2' => 'Сторінка <i>відстеження форумів</i> - це веб-інструмент управління (а не простір для дискусій або редагування). Вона відображає всі повідомлення на форумах сайту, як на загальному сайті, так і в адміністративній частині, та дозволяє управляти ними.',
	'info_liens_syndiques_3' => 'форуми',
	'info_liens_syndiques_4' => 'є',
	'info_liens_syndiques_5' => 'форум',
	'info_liens_syndiques_6' => 'є',
	'info_liens_syndiques_7' => 'очікує на перевірку',
	'info_liens_texte' => 'Посилання в тексті коментаря',
	'info_liens_titre' => 'Посилання в заголовку коментаря',
	'info_mode_fonctionnement_defaut_forum_public' => 'Усталені налаштування форумів на сайті',
	'info_nb_messages_forum' => '@nb@ повідомлень на форумі',
	'info_option_email' => 'Коли відвідувач сайту розміщує нове повідомлення у форумі, пов’язаному зі статтею, автори статті можуть отримувати повідомлення про це електронною поштою. Будь ласка, вкажіть для яких випадків використовувати цю опцію.',
	'info_pas_de_forum' => 'відключити форуми',
	'info_question_visiteur_ajout_document_forum' => 'Якщо ви дозволяєте відвідувачам додавати файли (документи, зображення, звуки...) до їхніх повідомлень на форумі, вкажіть нижче список дозволених розширень для файлів (наприклад, GIF, JPG, PNG, MP3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Якщо ви хочете дозволити завантаження  всіх видів документів,  поставте зірочк. Щоб заборонити завантаження - залиште поле порожнім',
	'info_selectionner_message' => 'Вибрати повідомлення:',
	'interface_formulaire' => 'Стандартний інтерфейс',
	'interface_onglets' => 'Інтерфейс з вкладками',
	'item_activer_forum_administrateur' => 'Увімкнути форум адміністраторів',
	'item_config_forums_prive_global' => 'Увімкнути форум авторів',
	'item_config_forums_prive_objets' => 'Увімкнути ці форуми',
	'item_desactiver_forum_administrateur' => 'Вимкнути форум адміністраторів',
	'item_non_config_forums_prive_global' => 'Вимкнути форум авторів',
	'item_non_config_forums_prive_objets' => 'Вимкнути ці форуми',

	// L
	'label_selectionner' => 'Обрати:',
	'lien_reponse_article' => 'Коментар до статті',
	'lien_reponse_breve_2' => 'Коментар до новини',
	'lien_reponse_message' => 'Відповісти на коментар',
	'lien_reponse_rubrique' => 'Коментар до рубрики',
	'lien_reponse_site_reference' => 'Коментар до сайту',
	'lien_vider_selection' => 'Очистити вибір',

	// M
	'messages_aucun' => 'Нема',
	'messages_meme_auteur' => 'Усі коментарі цього автора',
	'messages_meme_email' => 'Усі коментарі з цього email’у',
	'messages_meme_ip' => 'Усі коментарі з цього IP',
	'messages_off' => 'Видалені',
	'messages_perso' => 'Особисті',
	'messages_privadm' => 'Адміністратори',
	'messages_prive' => 'Внутрішні',
	'messages_privoff' => 'Видалені',
	'messages_privrac' => 'Загальні',
	'messages_prop' => 'Запропоновані',
	'messages_publie' => 'Опубліковано',
	'messages_spam' => 'Спам',
	'messages_tous' => 'Усі',

	// O
	'onglet_messages_internes' => 'Внутрішні повідомлення',
	'onglet_messages_publics' => 'Коментарі на сайті',
	'onglet_messages_vide' => 'Коментарі без тексту',

	// R
	'repondre_message' => 'Відповісти на коментар',

	// S
	'statut_off' => 'Видалити',
	'statut_original' => 'оригінал',
	'statut_prop' => 'Запропоновано',
	'statut_publie' => 'Опубліковано',
	'statut_spam' => 'Спам',

	// T
	'text_article_propose_publication_forum' => 'Подивіться форум, прикріплений до цієї статті (внизу сторінки)',
	'texte_en_cours_validation' => 'Статті, новини, форуми, запропоновані для публікації.',
	'texte_en_cours_validation_forum' => 'Подивіться форуми, які до них прикріплені',
	'texte_messages_publics' => 'Повідомлення на загальному сайті:',
	'titre_cadre_forum_administrateur' => 'Форум адміністраторів',
	'titre_cadre_forum_interne' => 'Внутрішній форум',
	'titre_config_forums_prive' => 'Форуми адміністративної частини',
	'titre_forum' => 'Форуми (коментарі)',
	'titre_forum_suivi' => 'Відстеження форумів',
	'titre_page_forum_suivi' => 'Відстеження форумів',
	'titre_selection_action' => 'Обрати',
	'tout_voir' => 'Переглянути всі повідомлення',

	// V
	'voir_messages_objet' => 'перегляд повідомлень',
];

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Нема повідомлень на форумі',

	// B
	'bouton_radio_articles_futurs' => 'тільки для майбутніх статей  (не приймати рішення по базі даних).',
	'bouton_radio_articles_tous' => 'до всіх статтей без винятків',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'до всіх статтей, крім тих, форум яких відключено.',
	'bouton_radio_enregistrement_obligatoire' => 'Потрібна реєстрація.  (Користувачі повинні зареєструватися, направивши свої електронні адреси до того, як зможуть розмістити внески).', # MODIF
	'bouton_radio_moderation_priori' => 'Премодерація (Внески  будуть відображатися публічно тільки після перевірки адміністраторами).', # MODIF
	'bouton_radio_modere_abonnement' => 'за підпискою',
	'bouton_radio_modere_posteriori' => 'пост-модерація',
	'bouton_radio_modere_priori' => 'премодерація',
	'bouton_radio_publication_immediate' => 'Публікація коментарів без перевірки  (адміністратори можуть   видалити їх).', # MODIF

	// D
	'documents_interdits_forum' => 'Заборонено додавати файли у коментарі форума',

	// E
	'erreur_enregistrement_message' => 'Ваше повідомлення не може бути записано через технічні проблеми.',
	'extensions_autorisees' => 'Авторизовані розширення:',
	'extensions_autorisees_toutes' => 'усі',

	// F
	'form_pet_message_commentaire' => 'Залишити коментар',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'Ви більше не маєте доступу до цих форумів.',
	'forum_attention_dix_caracteres' => 'Увага! Текст вашого коментаря має містити щонайменше 10 символів.',
	'forum_attention_message_non_poste' => 'Ваше коментар ще не опублікован на сайті!',
	'forum_attention_nb_caracteres_mini' => '<b>Увага!</b> Ваш коментар має бути не менше @min@ символів.',
	'forum_attention_trois_caracteres' => '<b>Увага!</b> Заголовок має бути не менше трьох символів.',
	'forum_attention_trop_caracteres' => '<b>Увага!</b> Ваш коментар містить (@compte@ caractères) символів, ми можемо його опублікувати якщо розмір не перевищує @max@ символів.',
	'forum_avez_selectionne' => 'Ви обрали:',
	'forum_cliquer_retour' => 'Натисніть <a href=\'@retour_forum@\'>сюди</a> аби продовжити.',
	'forum_envoyer' => 'Відправити',
	'forum_forum' => 'форум',
	'forum_info_modere' => 'На цьому форумі здійснюється премодерація: ваш коментар буде опубліковано після перевірки адміністратором.', # MODIF
	'forum_lien_hyper' => 'Гіпертекстове посилання',
	'forum_message' => 'Ваш коментар',
	'forum_message_definitif' => 'Надіслати до публікації',
	'forum_message_trop_long' => 'Ваш коментар занадто довгий. Максимальний розмір становить 20000 символів.',
	'forum_ne_repondez_pas' => 'Не відповідайте на цей лист, але перейдіть на форум за наступним посиланням:',
	'forum_page_url' => '(Якщо ваше повідомлення відноситься до статті, опублікованої на сайті, або до сторінки, що пропонує подальшу інформацію, ви можете вказати назву сторінки та її URL-адресу.)',
	'forum_permalink' => 'Постійне посилання на цей коментар',
	'forum_poste_par' => '@parauteur@ прокоментував вашу статтю «@titre@».',
	'forum_poste_par_court' => '@parauteur@ прокоментував',
	'forum_poste_par_generique' => '@parauteur@ прокоментував (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Хто ви?',
	'forum_saisie_texte_info' => 'Ви можете використовувати такі позначення в тексті: <code>[-&gt;url] {{жирний}} {курсив} &lt;quote&gt; &lt;code&gt;</code> і теги HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Щоб створити параграф двічі натисніть enter.',
	'forum_texte' => 'Текст повідомлення',
	'forum_titre' => 'Тема',
	'forum_url' => 'Ваш сайт',
	'forum_valider' => 'Підтвердіть вибір',
	'forum_voir_avant' => 'Попередній перегляд',
	'forum_votre_email' => 'Ваш email',
	'forum_votre_nom' => 'Ваше ім’я',
	'forum_vous_enregistrer' => 'Тільки зареєстровані користувачі можуть залишати коментарі. Якщо ви ще не зареєстровані, ви можете',
	'forum_vous_inscrire' => 'зареєструватися',

	// I
	'icone_bruler_message' => 'Помітити як спам',
	'icone_bruler_messages' => 'Поскаржитись на спам',
	'icone_legitimer_message' => 'Помітити як НЕ спам',
	'icone_poster_message' => 'Опублікувати коментар',
	'icone_suivi_forum' => 'Моніторинг форуму загального сайту: @nb_forums@ коментарі(в)',
	'icone_suivi_forums' => 'Управління форумами',
	'icone_supprimer_message' => 'Видалити коментар',
	'icone_supprimer_messages' => 'Видалити коментарі',
	'icone_valider_message' => 'Підтвердити коментар',
	'icone_valider_messages' => 'Опублікувати коментар',
	'icone_valider_repondre_message' => 'Затвердити та відповісти',
	'info_1_message_forum' => '1 повідомлення',
	'info_activer_forum_public' => 'Для активації форумів на публічній сторінці сайту оберіть режим модерації:',
	'info_appliquer_choix_moderation' => 'Застосувати режим модерації:',
	'info_config_forums_prive' => 'У приватній частині сайту ви можете активувати декілька типів форумів:',
	'info_config_forums_prive_admin' => 'Форум для адміністраторів сайту:', # MODIF
	'info_config_forums_prive_global' => 'Форум, відкритий для всіх редакторів:', # MODIF
	'info_config_forums_prive_objets' => 'Форум до кожної статті, новини, веб-сайту тощо:',
	'info_desactiver_forum_public' => 'Вимкнути використання форумів  на загальному сайті. Ви зможете дозволити коментарі до певної статті, але вони будуть заборонені до рубрик, новин тощо.',
	'info_envoi_forum' => 'Відправка форумів авторам статей', # MODIF
	'info_fonctionnement_forum' => 'Робота форуму:',
	'info_forcer_previsualisation_court' => 'Обов’язколвий попередній перегляд',
	'info_forcer_previsualisation_long' => 'Обов’язковий попередній перегляд перед відправкою коментаря',
	'info_forums_liees_mot' => 'Повідомлень на форумі, пов’язанному з цим ключовим словом',
	'info_gauche_suivi_forum_2' => 'Сторінка <i>відстеження форумів</i> - це веб-інструмент управління (а не простір для дискусій або редагування). Вона відображає всі повідомлення на форумах сайту, як на загальному сайті, так і в адміністративній частині, та дозволяє управляти ними.',
	'info_liens_syndiques_3' => 'форуми',
	'info_liens_syndiques_4' => 'є',
	'info_liens_syndiques_5' => 'форум',
	'info_liens_syndiques_6' => 'є',
	'info_liens_syndiques_7' => 'очікує на перевірку',
	'info_liens_texte' => 'Посилання в тексті коментаря',
	'info_liens_titre' => 'Посилання в заголовку коментаря',
	'info_mode_fonctionnement_defaut_forum_public' => 'Усталені налаштування форумів на сайті',
	'info_nb_messages_forum' => '@nb@ повідомлень на форумі',
	'info_option_email' => 'Коли відвідувач сайту розміщує нове повідомлення у форумі, пов’язаному зі статтею, автори статті можуть отримувати повідомлення про це електронною поштою. Будь ласка, вкажіть для яких випадків використовувати цю опцію.', # MODIF
	'info_pas_de_forum' => 'відключити форуми',
	'info_question_visiteur_ajout_document_forum' => 'Якщо ви дозволяєте відвідувачам додавати файли (документи, зображення, звуки...) до їхніх повідомлень на форумі, вкажіть нижче список дозволених розширень для файлів (наприклад, GIF, JPG, PNG, MP3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Якщо ви хочете дозволити завантаження  всіх видів документів,  поставте зірочк. Щоб заборонити завантаження - залиште поле порожнім',
	'info_selectionner_message' => 'Вибрати повідомлення:',
	'interface_formulaire' => 'Стандартний інтерфейс',
	'interface_onglets' => 'Інтерфейс з вкладками',
	'item_activer_forum_administrateur' => 'Увімкнути форум адміністраторів', # MODIF
	'item_config_forums_prive_global' => 'Увімкнути форум авторів', # MODIF
	'item_config_forums_prive_objets' => 'Увімкнути ці форуми',
	'item_desactiver_forum_administrateur' => 'Вимкнути форум адміністраторів', # MODIF
	'item_non_config_forums_prive_global' => 'Вимкнути форум авторів', # MODIF
	'item_non_config_forums_prive_objets' => 'Вимкнути ці форуми',

	// L
	'label_selectionner' => 'Обрати:',
	'lien_reponse_article' => 'Коментар до статті',
	'lien_reponse_breve_2' => 'Коментар до новини',
	'lien_reponse_message' => 'Відповісти на коментар',
	'lien_reponse_rubrique' => 'Коментар до рубрики',
	'lien_reponse_site_reference' => 'Коментар до сайту',
	'lien_vider_selection' => 'Очистити вибір',

	// M
	'messages_aucun' => 'Нема',
	'messages_meme_auteur' => 'Усі коментарі цього автора', # MODIF
	'messages_meme_email' => 'Усі коментарі з цього email’у',
	'messages_meme_ip' => 'Усі коментарі з цього IP',
	'messages_off' => 'Видалені',
	'messages_perso' => 'Особисті',
	'messages_privadm' => 'Адміністратори', # MODIF
	'messages_prive' => 'Внутрішні',
	'messages_privoff' => 'Видалені',
	'messages_privrac' => 'Загальні',
	'messages_prop' => 'Запропоновані',
	'messages_publie' => 'Опубліковано',
	'messages_spam' => 'Спам',
	'messages_tous' => 'Усі',

	// O
	'onglet_messages_internes' => 'Внутрішні повідомлення',
	'onglet_messages_publics' => 'Коментарі на сайті',
	'onglet_messages_vide' => 'Коментарі без тексту',

	// R
	'repondre_message' => 'Відповісти на коментар',

	// S
	'statut_off' => 'Видалити',
	'statut_original' => 'оригінал',
	'statut_prop' => 'Запропоновано',
	'statut_publie' => 'Опубліковано',
	'statut_spam' => 'Спам',

	// T
	'text_article_propose_publication_forum' => 'Подивіться форум, прикріплений до цієї статті (внизу сторінки)',
	'texte_en_cours_validation' => 'Статті, новини, форуми, запропоновані для публікації.',
	'texte_en_cours_validation_forum' => 'Подивіться форуми, які до них прикріплені',
	'texte_messages_publics' => 'Повідомлення на загальному сайті:',
	'titre_cadre_forum_administrateur' => 'Форум адміністраторів', # MODIF
	'titre_cadre_forum_interne' => 'Внутрішній форум',
	'titre_config_forums_prive' => 'Форуми адміністративної частини',
	'titre_forum' => 'Форуми (коментарі)',
	'titre_forum_suivi' => 'Відстеження форумів',
	'titre_page_forum_suivi' => 'Відстеження форумів',
	'titre_selection_action' => 'Обрати',
	'tout_voir' => 'Переглянути всі повідомлення',

	// V
	'voir_messages_objet' => 'перегляд повідомлень',
];
